Telemetry

Struct Telemetry 

pub struct Telemetry { /* private fields */ }
Telemetry initializer.

Implementations

Source

impl Telemetry

pub fn new(name: impl Into<String>) -> Self

Create a new telemetry resource.

pub fn name(self, name: impl Into<String>) -> Self

Override the default app name.

pub fn env(self, env_name: impl Into<String>) -> Self

Set the environment name.

pub fn endpoint(self, endpoint: impl Into<String>) -> Self

Set the OpenTelemetry endpoint.

pub fn build(self) -> Result<()>

Initializes telemetry using the provided configuration.

Errors

Returns an error if the telemetry system fails to initialize, such as if the OpenTelemetry exporter cannot be created or if setting the global subscriber fails.